==> calamares-settings-solydxk_4.17%2Br13.tar.xz: source/ts/calamares-solydxk_de.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="de" sourcelanguage="en_US">
<context>
    <name>show</name>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="40"/>
        <source>&lt;h3&gt;Thank you for choosing SolydXK&lt;/h3&gt;&lt;br /&gt;You&apos;ve chosen a Linux distribution that is:&lt;br /&gt;&lt;ul&gt;&lt;li&gt;Secure and stable&lt;/li&gt;&lt;li&gt;Fast and responsive&lt;/li&gt;&lt;li&gt;Desktop-ready&lt;/li&gt;&lt;/ul&gt;&lt;br /&gt;Enjoy this new release and thank you for choosing SolydXK.&lt;br /&gt;&lt;br /&gt;The installation takes 15-30 minutes, depending on your settings.</source>
        <translation>&lt;h3&gt;Vielen Dank dafür, dass Sie sich für SolydXK entschieden haben!&lt;/h3&gt;&lt;br /&gt;Ihre gewählte Linux Distribution hat die folgenden Eigenschaften:&lt;br /&gt;&lt;ul&gt;&lt;li&gt;Sicher und stabil&lt;/li&gt;&lt;li&gt;Schnell und ansprechend&lt;/li&gt;&lt;li&gt;Startklar zum Arbeiten&lt;/li&gt;&lt;/ul&gt;&lt;br /&gt;Genießen Sie die neue Version und Danke dafür, dass Sie sich für SolydXK entschieden haben!&lt;br /&gt;&lt;br /&gt;Abhängig von Ihren Einstellungen wird die Installation ca. 15-30 Minuten dauern.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="61"/>
        <source>&lt;h3&gt;Standing on the shoulders of Giants&lt;/h3&gt;&lt;br /&gt;SolydXK is a Debian-based GNU/Linux distribution derived from and compatible with Debian.&lt;br /&gt;&lt;br /&gt;SolydXK uses either the lightweight Xfce desktop for SolydX or the highly configurable and stunningly appealing KDE desktop for SolydK.&lt;br /&gt;&lt;br /&gt;Our innovations, the rapid development of Debian and the huge Debian package selection make SolydXK one of the most attractive desktop operating systems available to home users.</source>
        <translation>&lt;h3&gt;Auf den Schultern von Giganten stehend&lt;/h3&gt;&lt;br /&gt;SolydXK ist eine GNU/Linux Distribution, die auf Debian basiert und dazu voll kompatibel ist.&lt;br /&gt;&lt;br /&gt;SolydXK nutzt entweder den leichtgewichtigen Xfce Desktop für SolydX oder den in hohem Maße konfigurierbaren und atemberaubenden KDE Desktop für SolydK.&lt;br /&gt;&lt;br /&gt;Unsere Innovationen, die rasche Entwicklung von Debian und die riesige Auswahl an Debian-Paketen machen SolydXK zu einem der attraktivsten Desktop-Betriebssysteme für Heimanwender.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="81"/>
        <source>&lt;h3&gt;Out of the box&lt;/h3&gt;&lt;br /&gt;Firefox, Thunderbird, and LibreOffice come pre-installed in SolydXK, so you can get started immediately with the desktop and the Internet.&lt;br /&gt;&lt;br /&gt;Unlike other Linux distributions SolydXK is also ready to play your music, internet videos and more.&lt;br /&gt;&lt;br /&gt;A wide variety of software can be installed with a click of the mouse.&lt;br /&gt;&lt;br /&gt;SolydXK is compatible with most popular file formats such as: docx, xlsx, doc, xls, pdf, zip, rar, mp3, mpg, and many more.</source>
        <translation>&lt;h3&gt;Gebrauchsfertig eingerichtet&lt;/h3&gt;&lt;br /&gt;Firefox, Thunderbird und LibreOffice sind bei SolydXK vorinstalliert. Dadurch stehen Desktop und Internet unmittelbar zur Verfügung.&lt;br /&gt;&lt;br /&gt;Im Gegensatz zu anderen Linux Distributionen können Sie mit SolyXK sofort Musik hören oder Videos aus dem Internet anschauen.&lt;br /&gt;&lt;br /&gt;Eine große Vielfalt an Softwareprogrammen kann mit einem Mausklick installiert werden.&lt;br /&gt;&lt;br /&gt;SolydXK ist mit den meisten gängigen Dateiformaten wie z.B. docx, xlsx, doc, xls, pdf, zip, rar, mp3, mpg, und vielen anderen kompatibel.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="102"/>
        <source>&lt;h3&gt;Office tools are ready to use as soon as you install SolydXK&lt;/h3&gt;&lt;br /&gt;LibreOffice, a powerful office software suite, comes built into SolydXK.&lt;br /&gt;&lt;br /&gt;LibreOffice is very easy to learn and use.&lt;br /&gt;&lt;br /&gt;You can use it to create letters, presentations and spreadsheets, as well as diagrams and databases.&lt;br /&gt;&lt;br /&gt;LibreOffice uses the standard OpenDocument format and it works with documents from other popular office applications including WordPerfect and Microsoft Office.</source>
        <translation>&lt;h3&gt;Büroprogramme stehen sofort nach der Installation von SolydXK zur Verfügung&lt;/h3&gt;&lt;br /&gt;LibreOffice, eine leistungsfähige Textverarbeitung, ist in  SolydXK vorinstalliert.&lt;br /&gt;&lt;br /&gt;LibreOffice ist sehr einfach zu erlernen und zu verwenden.&lt;br /&gt;&lt;br /&gt;Sie können es verwenden, um Briefe, Präsentationen und Tabellen sowie Diagramme und Datenbanken zu erstellen.&lt;br /&gt;&lt;br /&gt;Libreoffice verwendet das Standard Opendocument-Format und funktioniert mit Dokumenten aus anderen gängigen Office-Anwendungen wie Wordperfect und Microsoft Office.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="123"/>
        <source>&lt;h3&gt;An alternative to mainstream operating systems&lt;/h3&gt;&lt;br /&gt;SolydXK is easy to use, powerful and configurable.&lt;br /&gt;&lt;br /&gt;SolydXK is safe and stable. Unlike other operating systems, it is not prone to computer viruses or spyware, it does not suffer from disk fragmentation, and it has no registry that requires periodic cleaning.&lt;br /&gt;&lt;br /&gt;SolydXK can detect other operating systems and install itself beside them.You can choose which operating system to launch when you start the computer.</source>
        <translation>&lt;h3&gt;Eine Alternative zu herkömmlichen Betriebssystemen&lt;/h3&gt;&lt;br /&gt;SolydXK ist einfach zu bedienen, leistungsstark und konfigurierbar.&lt;br /&gt;&lt;br /&gt;SolydXK ist sicher und stabil. Im Gegensatz zu anderen Betriebssystemen ist es nicht anfällig für Computerviren oder Spyware. Es leidet nicht unter Festplatten-Fragmentierung und hat keine Registy-Datenbank, die regelmäßige Reinigung erfordert.&lt;br /&gt;&lt;br /&gt;SolydXK erkennt bei der Installation automatisch andere bereits installierte Betriebssysteme und kann sich selbst neben diese installieren. Wenn Sie dann den Computer starten, können Sie wählen, welches Betriebssystem gestartet werden soll.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="143"/>
        <source>&lt;h3&gt;Safe updates&lt;/h3&gt;&lt;br /&gt;Some operating systems make updating your system harder than it really needs to be. SolydXK thinks upgrades should be quick and easy, and then get out of the way.&lt;br /&gt;&lt;br /&gt;The Update Manager sits discreetly in your system tray and lets you know when updates are available. You don&apos;t have to apply updates when you don&apos;t want to. The Update Manager won&apos;t pop up or annoy you in any way.&lt;br /&gt;&lt;br /&gt;All updated files are maintained and closely checked by trusted developers and maintainers.&lt;br /&gt;&lt;br /&gt;All files are stored in special secure repositories for your use.&lt;br /&gt;&lt;br /&gt;The security repository is synchronized daily.</source>
        <translation>&lt;h3&gt;Sichere Updates&lt;/h3&gt;&lt;br /&gt;Einige Betriebssysteme machen die Aktualisierung Ihres Systems schwieriger als es wirklich sein muss. Der SolydXK Philosophie zufolge sollten Upgrades unkompliziert, schnell und einfach sein.&lt;br /&gt;&lt;br /&gt;Der Update Manager wartet im Systemtray and benachrichtigt Sie über die Verfügbarkeit von Updates. Updates werden nur auf Ihren Wunsch hin installiert. Der Update Manager wird kein gesondertes Fenster öffnen oder Sie sonst belästigen.&lt;br /&gt;&lt;br /&gt;Alle aktualisierten Dateien werden von von vertrauenswürdigen Entwicklern und Maintainern überprüft und gewartet.&lt;br /&gt;&lt;br /&gt;Alle Dateien werden in speziellen sicheren Repositorys für Ihre Verwendung gespeichert.&lt;br /&gt;&lt;br /&gt;Das Sicherheitsrepository wird täglich synchronisiert.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="165"/>
        <source>&lt;h3&gt;A great community&lt;/h3&gt;&lt;br /&gt;SolydXK users are happy to share their passion and enthusiasm and are eager to help. Don&apos;t hesitate to ask questions on the forums or to get involved in the community.&lt;br /&gt;&lt;br /&gt;Send us your feedback and tell us about your experience. We&apos;ll listen to your ideas and use them to further improve SolydXK.</source>
        <translation>&lt;h3&gt;Eine großartige Gemeinschaft&lt;/h3&gt;&lt;br /&gt;SolydXK Anwender teilen gerne ihre Leidenschaft und Begeisterung und sind bestrebt, anderen zu helfen. Zögern Sie nicht, Fragen im Forum stellen oder sich in der Gemeinschaft zu engagieren.&lt;br /&gt;&lt;br /&gt;Senden Sie uns Ihr Feedback und schreiben Sie uns über Ihre Erfahrungen. Wir werden Ihre Vorschläge anhören und sie dazu nutzen, SolydXK weiter zu verbessern.</translation>
    </message>
</context>
</TS>

==> calamares-settings-solydxk_4.27%2Br13.tar.xz: source/ts/calamares-solydxk_de.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="de" sourcelanguage="en_US">
<context>
    <name>show</name>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="40"/>
        <source>&lt;h3&gt;Thank you for choosing SolydXK&lt;/h3&gt;&lt;br /&gt;You&apos;ve chosen a Linux distribution that is:&lt;br /&gt;&lt;ul&gt;&lt;li&gt;Secure and stable&lt;/li&gt;&lt;li&gt;Fast and responsive&lt;/li&gt;&lt;li&gt;Desktop-ready&lt;/li&gt;&lt;/ul&gt;&lt;br /&gt;Enjoy this new release and thank you for choosing SolydXK.&lt;br /&gt;&lt;br /&gt;The installation takes 15-30 minutes, depending on your settings.</source>
        <translation>&lt;h3&gt;Vielen Dank dafür, dass Sie sich für SolydXK entschieden haben!&lt;/h3&gt;&lt;br /&gt;Ihre gewählte Linux Distribution hat die folgenden Eigenschaften:&lt;br /&gt;&lt;ul&gt;&lt;li&gt;Sicher und stabil&lt;/li&gt;&lt;li&gt;Schnell und ansprechend&lt;/li&gt;&lt;li&gt;Startklar zum Arbeiten&lt;/li&gt;&lt;/ul&gt;&lt;br /&gt;Genießen Sie die neue Version und Danke dafür, dass Sie sich für SolydXK entschieden haben!&lt;br /&gt;&lt;br /&gt;Abhängig von Ihren Einstellungen wird die Installation ca. 15-30 Minuten dauern.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="61"/>
        <source>&lt;h3&gt;Standing on the shoulders of Giants&lt;/h3&gt;&lt;br /&gt;SolydXK is a Debian-based GNU/Linux distribution derived from and compatible with Debian.&lt;br /&gt;&lt;br /&gt;SolydXK uses either the lightweight Xfce desktop for SolydX or the highly configurable and stunningly appealing KDE desktop for SolydK.&lt;br /&gt;&lt;br /&gt;Our innovations, the rapid development of Debian and the huge Debian package selection make SolydXK one of the most attractive desktop operating systems available to home users.</source>
        <translation>&lt;h3&gt;Auf den Schultern von Giganten stehend&lt;/h3&gt;&lt;br /&gt;SolydXK ist eine GNU/Linux Distribution, die auf Debian basiert und dazu voll kompatibel ist.&lt;br /&gt;&lt;br /&gt;SolydXK nutzt entweder den leichtgewichtigen Xfce Desktop für SolydX oder den in hohem Maße konfigurierbaren und atemberaubenden KDE Desktop für SolydK.&lt;br /&gt;&lt;br /&gt;Unsere Innovationen, die rasche Entwicklung von Debian und die riesige Auswahl an Debian-Paketen machen SolydXK zu einem der attraktivsten Desktop-Betriebssysteme für Heimanwender.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="81"/>
        <source>&lt;h3&gt;Out of the box&lt;/h3&gt;&lt;br /&gt;Firefox, Thunderbird, and LibreOffice come pre-installed in SolydXK, so you can get started immediately with the desktop and the Internet.&lt;br /&gt;&lt;br /&gt;Unlike other Linux distributions SolydXK is also ready to play your music, internet videos and more.&lt;br /&gt;&lt;br /&gt;A wide variety of software can be installed with a click of the mouse.&lt;br /&gt;&lt;br /&gt;SolydXK is compatible with most popular file formats such as: docx, xlsx, doc, xls, pdf, zip, rar, mp3, mpg, and many more.</source>
        <translation>&lt;h3&gt;Gebrauchsfertig eingerichtet&lt;/h3&gt;&lt;br /&gt;Firefox, Thunderbird und LibreOffice sind bei SolydXK vorinstalliert. Dadurch stehen Desktop und Internet unmittelbar zur Verfügung.&lt;br /&gt;&lt;br /&gt;Im Gegensatz zu anderen Linux Distributionen können Sie mit SolyXK sofort Musik hören oder Videos aus dem Internet anschauen.&lt;br /&gt;&lt;br /&gt;Eine große Vielfalt an Softwareprogrammen kann mit einem Mausklick installiert werden.&lt;br /&gt;&lt;br /&gt;SolydXK ist mit den meisten gängigen Dateiformaten wie z.B. docx, xlsx, doc, xls, pdf, zip, rar, mp3, mpg, und vielen anderen kompatibel.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="102"/>
        <source>&lt;h3&gt;Office tools are ready to use as soon as you install SolydXK&lt;/h3&gt;&lt;br /&gt;LibreOffice, a powerful office software suite, comes built into SolydXK.&lt;br /&gt;&lt;br /&gt;LibreOffice is very easy to learn and use.&lt;br /&gt;&lt;br /&gt;You can use it to create letters, presentations and spreadsheets, as well as diagrams and databases.&lt;br /&gt;&lt;br /&gt;LibreOffice uses the standard OpenDocument format and it works with documents from other popular office applications including WordPerfect and Microsoft Office.</source>
        <translation>&lt;h3&gt;Büroprogramme stehen sofort nach der Installation von SolydXK zur Verfügung&lt;/h3&gt;&lt;br /&gt;LibreOffice, eine leistungsfähige Textverarbeitung, ist in  SolydXK vorinstalliert.&lt;br /&gt;&lt;br /&gt;LibreOffice ist sehr einfach zu erlernen und zu verwenden.&lt;br /&gt;&lt;br /&gt;Sie können es verwenden, um Briefe, Präsentationen und Tabellen sowie Diagramme und Datenbanken zu erstellen.&lt;br /&gt;&lt;br /&gt;Libreoffice verwendet das Standard Opendocument-Format und funktioniert mit Dokumenten aus anderen gängigen Office-Anwendungen wie Wordperfect und Microsoft Office.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="123"/>
        <source>&lt;h3&gt;An alternative to mainstream operating systems&lt;/h3&gt;&lt;br /&gt;SolydXK is easy to use, powerful and configurable.&lt;br /&gt;&lt;br /&gt;SolydXK is safe and stable. Unlike other operating systems, it is not prone to computer viruses or spyware, it does not suffer from disk fragmentation, and it has no registry that requires periodic cleaning.</source>
        <translation>&lt;h3&gt;Eine Alternative zu herkömmlichen Betriebssystemen&lt;/h3&gt;&lt;br /&gt;SolydXK ist einfach zu bedienen, leistungsstark und konfigurierbar.&lt;br /&gt;&lt;br /&gt;SolydXK ist sicher und stabil. Im Gegensatz zu anderen Betriebssystemen ist es nicht anfällig für Computerviren oder Spyware. Es leidet nicht unter Festplatten-Fragmentierung und hat keine Registy-Datenbank, die regelmäßige Reinigung erfordert.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="142"/>
        <source>&lt;h3&gt;Safe updates&lt;/h3&gt;&lt;br /&gt;Some operating systems make updating your system harder than it really needs to be. SolydXK thinks upgrades should be quick and easy, and then get out of the way.&lt;br /&gt;&lt;br /&gt;The Update Manager sits discreetly in your system tray and lets you know when updates are available. You don&apos;t have to apply updates when you don&apos;t want to. The Update Manager won&apos;t pop up or annoy you in any way.&lt;br /&gt;&lt;br /&gt;All updated files are maintained and closely checked by trusted developers and maintainers.&lt;br /&gt;&lt;br /&gt;All files are stored in special secure repositories for your use.&lt;br /&gt;&lt;br /&gt;The security repository is synchronized daily.</source>
        <translation>&lt;h3&gt;Sichere Updates&lt;/h3&gt;&lt;br /&gt;Einige Betriebssysteme machen die Aktualisierung Ihres Systems schwieriger als es wirklich sein muss. Der SolydXK Philosophie zufolge sollten Upgrades unkompliziert, schnell und einfach sein.&lt;br /&gt;&lt;br /&gt;Der Update Manager wartet im Systemtray and benachrichtigt Sie über die Verfügbarkeit von Updates. Updates werden nur auf Ihren Wunsch hin installiert. Der Update Manager wird kein gesondertes Fenster öffnen oder Sie sonst belästigen.&lt;br /&gt;&lt;br /&gt;Alle aktualisierten Dateien werden von von vertrauenswürdigen Entwicklern und Maintainern überprüft und gewartet.&lt;br /&gt;&lt;br /&gt;Alle Dateien werden in speziellen sicheren Repositorys für Ihre Verwendung gespeichert.&lt;br /&gt;&lt;br /&gt;Das Sicherheitsrepository wird täglich synchronisiert.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="164"/>
        <source>&lt;h3&gt;A great community&lt;/h3&gt;&lt;br /&gt;SolydXK users are happy to share their passion and enthusiasm and are eager to help. Don&apos;t hesitate to ask questions on the forums or to get involved in the community.&lt;br /&gt;&lt;br /&gt;Send us your feedback and tell us about your experience. We&apos;ll listen to your ideas and use them to further improve SolydXK.</source>
        <translation>&lt;h3&gt;Eine großartige Gemeinschaft&lt;/h3&gt;&lt;br /&gt;SolydXK Anwender teilen gerne ihre Leidenschaft und Begeisterung und sind bestrebt, anderen zu helfen. Zögern Sie nicht, Fragen im Forum stellen oder sich in der Gemeinschaft zu engagieren.&lt;br /&gt;&lt;br /&gt;Senden Sie uns Ihr Feedback und schreiben Sie uns über Ihre Erfahrungen. Wir werden Ihre Vorschläge anhören und sie dazu nutzen, SolydXK weiter zu verbessern.</translation>
    </message>
</context>
</TS>
